pub fn execute<S: ProjectionStore>(
store: &mut S,
plan: &QueryPlan,
table_def: &TableDef,
) -> Result<QueryResult>Expand description
Executes a query plan against the current store state.
pub fn execute<S: ProjectionStore>(
store: &mut S,
plan: &QueryPlan,
table_def: &TableDef,
) -> Result<QueryResult>Executes a query plan against the current store state.