pub struct PreparedQuery { /* private fields */ }Expand description
A prepared (planned) query ready for execution.
Implementations
Sourceimpl PreparedQuery
impl PreparedQuery
Sourcepub fn execute<S: ProjectionStore>(&self, store: &mut S) -> Result<QueryResult>
pub fn execute<S: ProjectionStore>(&self, store: &mut S) -> Result<QueryResult>
Executes this prepared query against the current store state.
Sourcepub fn execute_at<S: ProjectionStore>(
&self,
store: &mut S,
position: Offset,
) -> Result<QueryResult>
pub fn execute_at<S: ProjectionStore>( &self, store: &mut S, position: Offset, ) -> Result<QueryResult>
Executes this prepared query at a specific log position.
Sourcepub fn columns(&self) -> &[ColumnName]
pub fn columns(&self) -> &[ColumnName]
Returns the column names this query will return.
Sourcepub fn table_name(&self) -> &str
pub fn table_name(&self) -> &str
Returns the table name being queried.