TableDef

Struct TableDef 

pub struct TableDef {
    pub table_id: TableId,
    pub columns: Vec<ColumnDef>,
    pub primary_key: Vec<ColumnName>,
    pub indexes: Vec<IndexDef>,
}
Definition of a table in the schema.

Fields

table_id: TableId

Underlying store table ID.

columns: Vec<ColumnDef>

Column definitions in order.

primary_key: Vec<ColumnName>

Primary key column names (in order).

indexes: Vec<IndexDef>

Secondary indexes on this table.

Implementations

Source

impl TableDef

pub fn new( table_id: TableId, columns: Vec<ColumnDef>, primary_key: Vec<ColumnName>, ) -> Self

Creates a new table definition.

pub fn with_index(self, index: IndexDef) -> Self

Adds an index to this table definition.

pub fn indexes(&self) -> &[IndexDef]

Returns all indexes for this table.

pub fn find_index_for_column(&self, column: &ColumnName) -> Option<&IndexDef>

Finds an index that can be used for the given column.

pub fn find_column(&self, name: &ColumnName) -> Option<(usize, &ColumnDef)>

Finds a column by name.

pub fn is_primary_key(&self, name: &ColumnName) -> bool

Returns true if the given column is part of the primary key.

pub fn primary_key_position(&self, name: &ColumnName) -> Option<usize>

Returns the index of a column in the primary key.

pub fn primary_key_indices(&self) -> Vec<usize>

Returns the column indices that form the primary key.